pub struct GeminiModel { /* private fields */ }Implementations
Sourceimpl GeminiModel
impl GeminiModel
pub fn new(api_key: impl Into<String>, model: impl Into<String>) -> Result<Self>
pub fn with_retry_config(self, retry_config: RetryConfig) -> Self
pub fn set_retry_config(&mut self, retry_config: RetryConfig)
pub fn retry_config(&self) -> &RetryConfig
Sourcepub async fn create_cached_content(
&self,
system_instruction: &str,
tools: &HashMap<String, Value>,
ttl_seconds: u32,
) -> Result<String>
pub async fn create_cached_content( &self, system_instruction: &str, tools: &HashMap<String, Value>, ttl_seconds: u32, ) -> Result<String>
Create a cached content resource with the given system instruction, tools, and TTL.
Returns the cache name (e.g., “cachedContents/abc123”) on success.
The cache is created using the model configured on this GeminiModel instance.
Sourcepub async fn delete_cached_content(&self, name: &str) -> Result<()>
pub async fn delete_cached_content(&self, name: &str) -> Result<()>
Delete a cached content resource by name.